@@ -1,4 +1,8 @@
-from utils import read_mat_file
+try:
+    from ..utils.data_loader import read_mat_file
+except:
+    from utils.data_loader import read_mat_file
+
 from .preprocess import normalize_data
 from .io_helper import save_windowed_dataset_hdf5
 import numpy as np
